# Generated by Django 5.2.1 on 2025-05-22 09:52

import django.db.models.deletion
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='WebhookRegistry',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('name', models.CharField(help_text='Name of this webhook', max_length=255)),
                ('event_signals', models.JSONField(default=list, help_text='Event types that trigger this webhook (e.g., CREATE, UPDATE, DELETE)')),
                ('endpoint', models.CharField(help_text='URL to send the webhook to', max_length=255)),
                ('secret', models.CharField(default=uuid.uuid4, help_text='Secret key for webhook authentication via X-Secret header', max_length=64)),
                ('headers', models.JSONField(blank=True, default=dict, help_text='Additional headers to send with the webhook (JSON format)')),
                ('keep_last_response', models.BooleanField(default=True, help_text='Whether to store the last response received')),
                ('last_response', models.TextField(blank=True, help_text='Last response received from the webhook endpoint', null=True)),
                ('last_success', models.DateTimeField(blank=True, help_text='Timestamp of last successful delivery', null=True)),
                ('last_failure', models.DateTimeField(blank=True, help_text='Timestamp of last failed delivery', null=True)),
                ('max_retries', models.PositiveIntegerField(blank=True, default=3, help_text='Maximum number of delivery attempts', null=True)),
                ('retry_delay', models.PositiveIntegerField(blank=True, default=60, help_text='Seconds to wait between retry attempts', null=True)),
                ('use_async', models.BooleanField(blank=True, default=None, help_text='Whether to use async delivery (None = use system default)', null=True)),
                ('is_active', models.BooleanField(default=True, help_text='Whether this webhook is active')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('content_type', models.ForeignKey(help_text='The model this webhook is associated with', on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'verbose_name': 'Webhook',
                'verbose_name_plural': 'Webhooks',
                'db_table': 'django_webhook_subscriber_webhook_registry',
                'ordering': ['-created_at'],
            },
        ),
        migrations.CreateModel(
            name='WebhookDeliveryLog',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('event_signal', models.CharField(help_text='The event type that triggered this delivery', max_length=255)),
                ('payload', models.JSONField(help_text='The payload that was sent')),
                ('response_status', models.IntegerField(blank=True, help_text='HTTP status code of the response', null=True)),
                ('response_body', models.TextField(blank=True, help_text='The body of the response received', null=True)),
                ('error_message', models.TextField(blank=True, help_text='Error message if the delivery failed', null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('webhook', models.ForeignKey(help_text='The webhook that was delivered', on_delete=django.db.models.deletion.CASCADE, related_name='delivery_logs', to='django_webhook_subscriber.webhookregistry')),
            ],
            options={
                'verbose_name': 'Webhook Delivery Log',
                'verbose_name_plural': 'Webhook Delivery Logs',
                'db_table': 'django_webhook_subscriber_webhook_delivery_log',
                'ordering': ['-created_at'],
            },
        ),
    ]
